"use strict";

import React, { useMemo } from 'react';
import { Platform, ScrollView, StyleSheet, Text, View } from 'react-native';
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter';
import { getRNStylesFromShikiStyle } from '../../utils/style-transformer';
import { jsx as _jsx } from "react/jsx-runtime";
const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
// Helper function to extract theme registration from Shiki theme input
function getThemeRegistration(theme) {
  if ('default' in theme) {
    return theme.default;
  }
  return theme;
}
const baseStyles = StyleSheet.create({
  scrollView: {
    flex: 1,
    minHeight: 20
  },
  lineContainer: {
    flexDirection: 'row',
    flexWrap: 'wrap',
    paddingHorizontal: 16,
    paddingVertical: 8
  },
  token: {
    fontFamily: monospaceFont,
    fontSize: 14
  },
  container: {
    flex: 1
  }
});
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme,
  fontSize = 14
}) => {
  const stylesheet = useMemo(() => {
    const themeRegistration = getThemeRegistration(theme);
    const styles = getRNStylesFromShikiStyle(themeRegistration);
    return StyleSheet.create({
      ...styles,
      editor: {
        backgroundColor: themeRegistration.colors?.['editor.background'] || '#1e1e1e'
      },
      token: {
        ...baseStyles.token,
        fontSize,
        color: themeRegistration.colors?.['editor.foreground'] || '#d4d4d4'
      }
    });
  }, [theme, fontSize]);
  const {
    tokens
  } = useSyntaxHighlighter({
    text,
    language,
    languageId,
    theme
  });
  const renderToken = (token, index, lineIndex) => {
    const styles = [stylesheet.token];

    // Add token-specific styles from stylesheet based on scope
    const tokenScopes = Array.isArray(token.scope) ? token.scope : [token.scope];
    tokenScopes.forEach(scope => {
      if (stylesheet[scope]) {
        styles.push(stylesheet[scope]);
      }
    });

    // Add token-specific styles from the token itself
    const tokenStyles = {};
    if (token.color) {
      tokenStyles.color = token.color;
    }
    if (token.fontStyle === 'italic') {
      tokenStyles.fontStyle = 'italic';
    }
    if (token.fontWeight === 'bold') {
      tokenStyles.fontWeight = 'bold';
    }
    if (Object.keys(tokenStyles).length > 0) {
      styles.push(tokenStyles);
    }
    const finalStyle = StyleSheet.flatten(styles);
    return /*#__PURE__*/_jsx(Text, {
      style: finalStyle,
      children: token.content.replace(/ /g, '\u00A0')
    }, `${lineIndex}-${index}`);
  };
  const renderLine = (line, lineIndex) => /*#__PURE__*/_jsx(View, {
    style: baseStyles.lineContainer,
    children: line.map((token, tokenIndex) => renderToken(token, tokenIndex, lineIndex))
  }, lineIndex);
  return /*#__PURE__*/_jsx(ScrollView, {
    horizontal: true,
    showsHorizontalScrollIndicator: Platform.OS !== 'web',
    style: [baseStyles.scrollView, stylesheet.editor],
    contentContainerStyle: baseStyles.container,
    children: tokens.map((line, index) => renderLine(line, index))
  });
};
export default SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map